@@ -1,3 +1,4 @@
+from __future__ import absolute_import
 try:
   import numpy
   from pipeline_display import *
@@ -126,7 +127,7 @@ class PlotableFlat(object) :
       for i in range(0, len(self.flats)) :
         slittrace = self.slittraces[i]
         ndegree = slittrace.getTableNcols(i+1) - 1
-        nslits = slittrace.getTableNrows(i+1) / 2
+        nslits = slittrace.getTableNrows(i+1) // 2
         self.nslits.append(nslits)
         degreecols = []
         for deg in range(ndegree):
@@ -587,8 +588,8 @@ class PlotableExtractedScience :
 
       extractedscience_flux_cal = self.extractedfluxcalibratedsciences[i]
       if extractedscience_flux_cal is not None:
-      	extractedscience_flux_cal.readImage(read_ext)
-	self.bunit_flux_cal.append(extractedscience_flux_cal.readKeyword('BUNIT', 0))
+        extractedscience_flux_cal.readImage(read_ext)
+        self.bunit_flux_cal.append(extractedscience_flux_cal.readKeyword('BUNIT', 0))
       
       read_ext = read_ext + 1
 
@@ -619,7 +620,7 @@ class PlotableExtractedScience :
     self.flux = self.extractedsciences[self.ext_sel].image[self.obj_id-1,:]
     self.flux_cal = None
     if(self.extractedfluxcalibratedsciences[self.ext_sel] is not None):
-    	self.flux_cal = self.extractedfluxcalibratedsciences[self.ext_sel].image[self.obj_id-1,:]
+      self.flux_cal = self.extractedfluxcalibratedsciences[self.ext_sel].image[self.obj_id-1,:]
 
   def selectObject(self, obj_id):
     self.obj_id = obj_id
@@ -636,16 +637,16 @@ class PlotableExtractedScience :
     units = self.bunit_extracted[self.ext_sel]
 
     if(self.plot_flux_cal and self.flux_cal is not None):
-    	units = self.bunit_flux_cal[self.ext_sel]
+      units = self.bunit_flux_cal[self.ext_sel]
 
     self.spectrumdisplay.setLabels('Lambda', 'Total Flux ['+units+']')
-    	    
+        
     if(not self.plot_flux_cal):
-    	self.spectrumdisplay.display(subplot, title, tooltip, self.wave[self.ext_sel], self.flux,
+      self.spectrumdisplay.display(subplot, title, tooltip, self.wave[self.ext_sel], self.flux,
                                 autolimits = True)
 
     elif(self.flux_cal is not None):
-    	self.spectrumdisplay.display(subplot, title, tooltip, self.wave[self.ext_sel], self.flux_cal,
+      self.spectrumdisplay.display(subplot, title, tooltip, self.wave[self.ext_sel], self.flux_cal,
                                 autolimits = True)
 
 class PlotableSpecPhot :
