@@ -621,20 +621,27 @@ add_flux_data(irplib_sdp_spectrum * dest, const cpl_propertylist * plist){
 }
 
 static double calc_snr(const irplib_sdp_spectrum * spectrum){
-	const cpl_array * flx = irplib_sdp_spectrum_get_column_data(spectrum, flux_clmn_name);
-	const cpl_array * err = irplib_sdp_spectrum_get_column_data(spectrum, flux_clmn_err_name);
+    const cpl_array * flx = irplib_sdp_spectrum_get_column_data(spectrum, flux_clmn_name);
+    const cpl_array * err = irplib_sdp_spectrum_get_column_data(spectrum, flux_clmn_err_name);
 
-	cpl_array * div = cpl_array_duplicate(flx);
-	cpl_array_divide(div, err);
-	const double ret = cpl_array_get_median(div);
-	cpl_array_delete(div);
+    cpl_array * div = cpl_array_duplicate(flx);
+    cpl_array_divide(div, err);
+    int valid;
+    for(int i=0; i<cpl_array_get_size(flx); ++i)
+        if(cpl_array_get_double(flx, i, &valid)==-1 &&
+           cpl_array_get_double(err, i, &valid)==-1)
+            cpl_array_set_invalid(div, i);
 
-	if(cpl_error_get_code()) {
-		cpl_error_reset();
-		return NAN;
-	}
+    const double ret = cpl_array_get_median(div);
+    cpl_array_delete(div);
 
-	return ret;
+    if(cpl_error_get_code()) 
+    {
+        cpl_error_reset();
+        return NAN;
+    }
+
+    return ret;
 }
 
 static bool add_snr(irplib_sdp_spectrum * spectrum){
